country_and_time = {
    "afghanistan": "4:30",
    "albania": "2:00",
    "algeria": "1:00",
    "andorra": "2:00",
    "angola": "1:00",
    "antigua and barbuda": "-4:00",
    "argentina": "-3:00",
    "armenian": "4:00",
    "australian western standard time": "8:00",
    "australian central western standard time": "8:45",
    "australian central standard time": "9:30",
    "australian eastern standard time": "10:00",
    "lord howe standard time": "10:30",
    "austria": "2:00",
    "azerbaijan": "4:00",
    "bahamas": "-4:00",
    "bahrain": "3:00",
    "bangladesh": "6:00",
    "barbados": "-4:00",
    "belarus": "3:00",
    "belgium": "2:00",
    "belize": "-6:00",
    "benin": "1:00",
    "bhutan": "6:00",
    "bolivia": "-4:00",
    "bosnia and herzegovina": "2:00",
    "botswana": "2:00",
    "brunei": "8:00",
    "bulgaria": "3:00",
    "burkina faso": "0:00",
    "burundi": "2:00",
    "ivory coast": "0:00",
    "cape verde": "-1:00",
    "cambodia": "7:00",
    "cameroon": "1:00",
    "newfoundland daylight time": "-2:30",
    "atlantic daylight time": "-3:00",
    "eastern daylight time": "-4:00",
    "central daylight time": "-5:00",
    "mountain daylight time": "-6:00",
    "pacific daylight time": "-7:00",
    "chad": "1:00",
    "chile standard time": "-4:00",
    "china": "8:00",
    "columbia": "-5:00",
    "comoros": "3:00",
    "congo (congo-brazzaville)": "1:00",
    "costa rica": "-6:00",
    "croatia": "2:00",
    "cuba": "-4:00",
    "cyprus": "3:00",
    "czechia": "2:00",
    "west africa time": "1:00",
    "central africa time": "2:00",
    "denmark": "2:00",
    "djibouti": "3:00",
    "dominica": "-4:00",
    "dominican republic": "-4:00",
    "columbia time": "-5:00",
    "central standard time": "-6:00",
    "fiji": "12:00",
    "finland": "3:00",
    "at paris": "2:00",
    "tahiti time": "-10:00",
    "marquesas time": "-9:30",
    "gambier time": "-9:00",
    "easter island standard time": "-8:00",
    "atlantic standard time": "-4:00",
    "french guiana time": "-3:00",
    "pierre & miquelon daylight time": "-2:00",
    "eastern africa time": "3:00",
    "reunion time": "4:00",
    "french southern and antarctic time": "5:00",
    "new caledonia time": "11:00",
    "wallis and futuna Time": "12:00",
    "gabon": "1:00",
    "gambia": "0.00",
    "georgia": "-4:00",
    "germany": "2:00",
    "ghana": "0:00",
    "greece": "3:00",
    "grenada": "-4:00",
    "guatemala": "-6:00",
    "guinea": "0:00",
    "guinea-Bissau": "0:00",
    "guyana": "-4:00",
    "haiti": "-4:00",
    "holy See (vatican city)": "2:00",
    "honduras": "-6:00",
    "hungary": "2:00",
    "iceland": "0:00",
    "india": "5:30",
    "japan standard time": "9:00",
    "singapore standard time": "8:00",
    "western indonesian time": "7:00",
    "iran": "4:30",
    "iraq": "3:00",
    "ireland": "1:00",
    "israel": "3:00",
    "italy": "2:00",
    "jamaica": "-5:00",
    "japan": "9:00",
    "jordan": "3:00",
    "alma-ata time": "6:00",
    "azbekistan time": "5:00",
    "kenya": "3:00",
    "gilbert island time": "12:00",
    "west samoa time": "13:00",
    "kuwait": "3:00",
    "kyrgyzstan": "6:00",
    "laos": "7:00",
    "latvia": "3:00",
    "lebanon": "3:00",
    "lesotho": "2:00",
    "liberia": "0:00",
    "libya": "2:00",
    "liechtenstein": "2:00",
    "lithuania": "3:00",
    "luxembourg": "2:00",
    "madagascar": "3:00",
    "malawi": "2:00",
    "malaysia": "8:00",
    "maldives": "5:00",
    "mali": "0:00",
    "malta": "2:00",
    "marshall islands": "12:00",
    "mauritania": "0:00",
    "mauritius": "4:00",
    "tijuana UTC": "-7:00",
    "la paz UTC": "-6:00",
    "chuuk Time": "10:00",
    "pohnpei Standard Time": "11:00",
    "kosrae Time": "11:00",
    "moldovo": "2:00",
    "monaco": "2:00",
    "ulaanbaatar time": "8:00",
    "montenegro": "2:00",
    "morocco": "1:00",
    "mozambique": "2:00",
    "myanmar": "6:30",
    "namibia": "+2:00",
    "nauru": "12:00",
    "nepal": "5:45",
    "netherlands": "2:00",
    "new zealand": "12:00",
    "nicaragua": "-6:00",
    "niger": "1:00",
    "nigeria": "1:00",
    "north korea": "9:00",
    "north macedonia": "2:00",
    "norway": "2:00",
    "oman": "4:00",
    "pakistan": "5:00",
    "palau": "9:00",
    "panama": "5:00",
    "papua new guinea": "10:00",
    "paraguay": "-4:00",
    "peru": "-5:00",
    "philippines": "8:00",
    "poland": "2:00",
    "azores summer time": "0:00",
    "western european summer time": "1:00",
    "qatar": "3:00",
    "romania": "3:00",
    "eastern European Time": "2:00",
    "moscow Standard Time": "3:00",
    "yekaterinburg Time": "5:00",
    "novosibirsk Time": "7:00",
    "krasnoyarsk Time": "7:00",
    "irkutsk Time UTC": "8:00",
    "yakutsk Time UTC": "9:00",
    "vladivostok Time": "10:00",
    "magadan Time": "11:00",
    "rwanda": "2:00",
    "saint kitts and nevis": "-4:00",
    "saint lucia": "-4:00",
    "saint vincent and the grenadines": "-4:00",
    "samoa": "+13:00",
    "san marino": "2:00",
    "sao tome and principe": "0:00",
    "saudi arabia": "3:00",
    "senegal": "0:00",
    "serbia": "2:00",
    "seychelles": "4:00",
    "sierra leone": "0:00",
    "singapore": "8:00",
    "slovakia": "2:00",
    "slovenia": "2:00",
    "solomon islands": "11:00",
    "somalia": "3:00",
    "south africa": "2:00",
    "south korea": "9:00",
    "south sudan": "3:00",
    "british summer time": "1:00",
    "central european summer time": "2:00",
    "sri lanka": "5:30",
    "state of palestine": "2:00",
    "sudan": "2:00",
    "suriname": "-3:00",
    "sweden": "2:00",
    "switzerland": "2:00",
    "syria": "3:00",
    "tajikistan": "5:00",
    "tanzania": "3:00",
    "thailand": "7:00",
    "timor-leste": "9:00",
    "togo": "0:00",
    "tonga": "13:00",
    "trinidad and tobago": "-4:00",
    "tunisia": "1:00",
    "turkey": "3:00",
    "turkmenistan": "5:00",
    "tuvalu": "12:00",
    "uganda": "3:00",
    "ukraine": "3:00",
    "united arab emirates": "4:00",
    "united kingdom": "1:00",
    "mountain standard time": "-7:00",
    "alaska daylight time": "-8:00",
    "hawaii-aleutian standard time": "-10:00",
    "uruguay": "-3:00",
    "uzbekistan": "+5:00",
    "vanuatu": "11:00",
    "venezuela": "-4:00",
    "vietnam": "7:00",
    "yemen": "3:00",
    "zambia": "2:00",
    "zimbabwe": "2:00"
}


def errors(str):
    if "IsADirectoryError" in str:
        raise IsADirectoryError(
            f"User input is not on the list of countries. \nPlease use list _of_timezones or else visit:-")
    if "TypeError" in str:
        raise TypeError(
            f"User input was not in the required data type('str')")


def country_time(country):
    type_of_var = str(type(country))

    if type_of_var != "<class 'str'>":
        raise TypeError("Error")

    try:
        return country_and_time[country]
    except:
        raise errors("IsADirectoryError")


country_time("vanuatu")



def australian_timezones():
    print("Australian Western Standard Time UTC +8:00")
    print("Australian Central Western Standard Time UTC +8:45")
    print("Australian Central Standard Time UTC +9:30")
    print("Australian Eastern Standard Time UTC +10:00")
    print("Lord Howe Standard Time UTC +10:30")


def canadian_timezones():
    print("Newfoundland DaylightTime UTC -2:30")
    print("Atlantic Daylight Time UTC -3:00")
    print("Eastern Daylight Time UTC -4:00")
    print("Central Daylight Time UTC -5:00")
    print("Mountain Daylight Time UTC -6:00")
    print("Pacific Daylight Time UTC -7:00")


def chilean_timezones():
    print("Chile Standard Time UTC -4:00")
    print("Colombia Time UTC -5:00")


def congo_timezones():
    print("West Africa Time UTC +1:00")
    print("Central Africa Time UTC +2:00")


def equador_timezones():
    print("Colombia Time UTC -5:00")
    print("Central Standard Time UTC -6:00")


def french_timezones():
    print("At Paris: (Central European Summer Time) UTC +2:00")
    print("Tahiti Time UTC -10:00")
    print("Marquesas Time UTC -9:30")
    print("Gambier Time UTC -9:00")
    print("Easter Island Standard Time UTC -8:00")
    print("Atlantic Standard Time UTC -4:00")
    print("French Guiana Time UTC -3:00")
    print("Pierre & Miquelon Daylight Time UTC -2:00")
    print("Eastern Africa Time UTC +3:00")
    print("Reunion Time UTC UTC +4:00")
    print("French Southern and Antarctic Time UTC +5:00")
    print("New Caledonia Time UTC +11:00")
    print("Wallis and Futuna Time UTC +12:00")


def indonesian_timezones():
    print("Japan Standard Time UTC +9:00")
    print("Singapore Standard Time (SST) UTC +8:00")
    print("Western Indonesian Time (WIB) UTC +7:00")


def kazakhstani_timezones():
    print("Alma-Ata Time UTC +6:00")
    print("Uzbekistan Time UTC +5:00")


def kiribatian_timezones():
    print("Gilbert Island Time UTC +12:00")
    print("West Samoa Time UTC +13:00")


def mexican_timezones():
    print("Tijuana UTC -7:00")
    print("La Paz UTC -6:00")


def micronesian_timezones():
    print("Chuuk Time UTC +10:00")
    print("Pohnpei Standard Time UTC +11:00")
    print("Kosrae Time UTC +11:00")


def mongolian_timezones():
    print("Novosibirsk Time UTC +7:00")
    print("Ulaanbaatar Time UTC +8:00")


def portugese_timezones():
    print("Azores Summer Time UTC +0:00")
    print("Western European Summer Time UTC +1:00")


def russian_timezones():
    print("Eastern European Time UTC +2:00")
    print("Moscow Standard Time UTC +3:00")
    print("Yekaterinburg Time UTC +5:00")
    print("Novosibirsk Time UTC +7:00")
    print("Krasnoyarsk Time UTC +7:00")
    print("Irkutsk Time UTC +8:00")
    print("Yakutsk Time UTC +9:00")
    print("Vladivostok Time UTC +10:00")
    print("Magadan Time Time UTC +11:00")


def spanish_timezones():
    print("British Summer Time UTC +1:00")
    print("Central European Summer Time UTC +2:00")


def usa_timezones():
    print("Eastern Daylight Time UTC -4:00")
    print("Central Daylight Time UTC -5:00")
    print("Mountain Daylight Time UTC -6:00")
    print("Pacific Daylight Time UTC -7:00")
    print("Mountain Standard Time UTC -7:00")
    print("Alaska Daylight Time UTC -8:00")
    print("Hawaii-Aleutian Standard Time UTC -10:00")


def a_countries():
    print("Afghanistan: (Afghanistan Time) UTC +4:30")
    print("Albania: (Central European Summer Time) UTC +2:00")
    print("Algeria: (Central European Time) UTC +1:00")
    print("Andorra: (Central European Summer Time) UTC +2:00")
    print("Angola: (West African Time) UTC +1:00")
    print("Antigua and Barbuda: (Atlantic Standard Time) UTC -4:00")
    print("Argentina: (Argentine Time) UTC -3:00")
    print("Armenia: (Armenian Time) UTC +4:00")
    print("Australia: has 5 time zones.")
    australian_timezones()
    print("Austria: (Central European Summer Time) UTC +2:00")
    print("Azerbaijan: (Azerbaijan Time) UTC +4:00")


def b_countries():
    print("Bahamas: (Eastern Daylight Time) UTC -4:00")
    print("Bahrain: (Arabia Standard Time) UTC +3:00")
    print("Bangladesh: (Bangladesh Standard Time) UTC +6:00")
    print("Barbados: (Atlantic Standard Time) UTC -4:00")
    print("Belarus: (Moscow Standard Time) UTC +3:00")
    print("Belgium: (Central European Summer Time) UTC +2:00")
    print("Belize: (Central Standard Time) UTC -6:00")
    print("Benin: (West Africa Time) UTC +1:00")
    print("Bhutan: (Bhutan Time) UTC +6:00")
    print("Bolivia: (Bolivia Time) UTC -4:00")
    print("Bosnia and Herzegovina: (Central European Summer Time) UTC +2:00")
    print("Botswana: (Central Africa Time) UTC +2:00")
    print("Brunei: (Brunei Darussalam Time) UTC +8:00")
    print("Bulgaria: (Eastern European Summer Time UTC) +3:00")
    print("Burkina Faso: (Greenwich Mean Time) UTC +0:00")
    print("Burundi: (Central Africa Time) UTC +2:00")


def c_countries():
    print("Ivory Coast: (Greenwich Mean Time) UTC +0:00")
    print("Cape Verde: (Cape Verde Time) UTC -1:00")
    print("Cambodia: (Indochina Time) UTC +7:00")
    print("Cameroon: (West Africa Time) UTC +1:00")
    print("Canada: has 6 time zones.")
    canadian_timezones()
    print("Chad: (West Africa Time) UTC +1:00")
    print("Chile: has 2 time zones.")
    chilean_timezones()
    print("China: (China Standard Time) UTC +8:00")
    print("Columbia: (Colombia Time) UTC -5:00")
    print("Comoros: (East Africa Time) UTC +3:00")
    print("Congo (Congo-Brazzaville): (West Africa Time) UTC +1:00")
    print("Costa Rica: (Central Standard Time) UTC -6:00")
    print("Croatia: (Central European Summer Time) UTC +2:00")
    print("Cuba: (Cuba Daylight Time) UTC -4:00")
    print("Cyprus: (Eastern European Summer Time) UTC +3:00")
    print("Czechia: (Central European Summer Time) UTC +2:00")


def d_countries():
    print("Democratic Republic of the Congo: has 2 time zones.")
    congo_timezones()
    print("Denmark: (Central European Summer Time) UTC +2:00")
    print("Djibouti: (East Africa Time) UTC +3:00")
    print("Dominica: (Atlantic Standard Time) UTC -4:00")
    print("Dominican Republic: (Atlantic Standard Time) UTC -4:00")


def e_countries():
    print("Ecuador: there are 2 time zones.")
    equador_timezones()
    print("Egypt: (Eastern European Time) UTC +2:00")
    print("El Salvador: (Central Standard Time) UTC -6:00")
    print("Equatorial Guinea: (West Africa Time) UTC +1:00")
    print("Eritrea: (East Africa Time) UTC +3:00")
    print("Estonia: (Eastern European Summer Time) UTC +3:00")
    print("Eswatini: (South Africa Standard Time) UTC +2:00")
    print("Ethiopia: (East Africa Time) UTC +3:00")


def f_countries():
    print("Fiji: (Fiji Time) UTC +12:00")
    print("Finland: (Eastern European Summer Time) UTC +3:00")
    print("France: has 12 time zones.")
    french_timezones()


def g_countries():
    print("Gabon: (West Africa Time) UTC +1:00")
    print("Gambia: (Greenwich Mean Time) UTC +0.00")
    print("Georgia: (Eastern Daylight Time) UTC -4:00")
    print("Germany: (Central European Summer Time) UTC +2:00")
    print("Ghana: (Greenwich Mean Time) UTC +0:00")
    print("Greece: (Eastern European Summer Time) UTC +3:00")
    print("Grenada: (Atlantic Standard Time) UTC -4:00")
    print("Guatemala: (Central Standard Time) UTC -6:00")
    print("Guinea: (Greenwich Mean Time) UTC +0:00")
    print("Guinea-Bissau: (Greenwich Mean Time) UTC +0:00")
    print("Guyana: (Guyana Time) UTC -4:00")


def h_countries():
    print("Haiti: (Eastern Daylight Time) UTC -4:00")
    print("Holy See (Vatican City): (Central European Summer Time) UTC +2:00")
    print("Honduras: (Central Standard Time) UTC -6:00")
    print("Hungary: (Central European Summer Time) UTC +2:00")


def i_countries():
    print("Iceland: (Greenwich Mean Time) UTC +0:00")
    print("India: (Indian Standard Time) UTC +5:30")
    print("Indonesia: has 3 time zones.")
    indonesian_timezones()
    print("Iran: (Iran Daylight Time) UTC +4:30")
    print("Iraq: (Arabia Standard Time) UTC +3:00")
    print("Ireland: (Irish Time Zone) UTC +1:00")
    print("Israel: (Israel Daylight Time) UTC +3:00")
    print("Italy: (Central European Summer Time) UTC +2:00")


def j_countries():
    print("Jamaica: (Eastern Standard Time) UTC -5:00")
    print("Japan: (Japan Standard Time) UTC +9:00")
    print("Jordan: (Eastern European Summer Time) UTC +3:00")


def k_countries():
    print("Kazakhstan: had two time zones.")
    kazakhstani_timezones()
    print("Kenya: (East Africa Time) UTC +3:00")
    print("Kiribati: has two time zones.")
    kiribatian_timezones()
    print("Kuwait: (Arabia Standard Time) UTC +3:00")
    print("Kyrgyzstan: (Kyrgyzstan Time) UTC +6:00")


def l_countries():
    print("Laos: (Indochina Time) UTC +7:00")
    print("Latvia: (Eastern European Summer Time) UTC +3:00")
    print("Lebanon: (Eastern European Summer Time) UTC +3:00")
    print("Lesotho: (South Africa Standard Time) UTC +2:00")
    print("Liberia: (Greenwich Mean Time) UTC +0:00")
    print("Libya: (Eastern European Time) UTC +2:00")
    print("Liechtenstein: (Central European Summer Time) UTC +2:00")
    print("Lithuania: (Eastern European Summer Time) UTC +3:00")
    print("Luxembourg: (Central European Summer Time) UTC +2:00")


def m_countries():
    print("Madagascar: (East Africa Time) UTC +3:00")
    print("Malawi: (Central Africa Time) UTC +2:00")
    print("Malaysia: (Malaysia Time) UTC +8:00")
    print("Maldives: (Maldives Time) UTC +5:00")
    print("Mali: (Greenwich Mean Time) UTC +0:00")
    print("Malta: (Central European Summer Time) UTC +2:00")
    print("Marshall Islands: (Marshall Islands Time) UTC +12:00")
    print("Mauritania: (Greenwich Mean Time) UTC +0:00")
    print("Mauritius: (Mauritius Time) UTC +4:00")
    print("Mexico: has two timezones.")
    mexican_timezones()
    print("Micronesia: has three time zones.")
    micronesian_timezones()
    print("Moldovo: (Eastern European Time) UTC +2:00")
    print("Monaco: (Central European Summer Time) UTC +2:00")
    print("Mongol: has two time zones.")
    mongolian_timezones()
    print("Montenegro: (Central European Summer Time) UTC +2:00")
    print("Morocco: (Western European Time) UTC +1:00")
    print("Mozambique: (Central Africa Time) UTC +2:00")
    print("Myanmar: (Myanmar Time) UTC +6:30")


def n_countries():
    print("Namibia: (Central Africa Time) UTC +2:00")
    print("Nauru: (Nauru Time) UTC +12:00")
    print("Nepal: (Nepal Time) UTC +5:45")
    print("Netherlands: (Central European Summer Time) UTC +2:00")
    print("New Zealand: (New Zealand Standard Time) UTC +12:00")
    print("Nicaragua: (Central Standard Time) UTC -6:00")
    print("Niger: (West Africa Time) UTC +1:00")
    print("Nigeria: (West Africa Time) UTC +1:00")
    print("North Korea: (Korean Standard Time) UTC +9:00")
    print("North Macedonia: (Central European Summer Time) UTC +2:00")
    print("Norway: (Central European Summer Time) UTC +2:00")


def o_countries():
    print("Oman: (Gulf Standard Time) UTC +4:00")


def p_countries():
    print("Pakistan: (Pakistan Standard Time) UTC +5:00")
    print("Palau:(Palau Time) UTC +9:00")
    print("Panama: (Eastern Standard Time) UTC -5:00")
    print("Papua New Guinea: (Papua New Guinea Time) UTC +10:00")
    print("Paraguay: (Paraguay Time) UTC -4:00")
    print("Peru: (Peru Time) UTC -5:00")
    print("Philippines: (Philippines Standard Time) UTC +8:00")
    print("Poland: (Central European Summer Time) UTC +2:00")
    print("Portugal: has two time zones.")
    portugese_timezones()


def q_countries():
    print("Qatar: (Arabia Standard Time) UTC +3:00")


def r_countries():
    print("Romania: (Eastern European Summer Time) UTC +3:00")
    print("Russia: has nine time zones.")
    russian_timezones()
    print("Rwanda: (Central Africa Time) UTC +2:00")


def s_countries():
    print("Saint Kitts and Nevis: (Atlantic Standard Time) UTC -4:00")
    print("Saint Lucia: (Atlantic Standard Time) UTC -4:00")
    print("Saint Vincent and the Grenadines: (Atlantic Standard Time) UTC -4:00")
    print("Samoa: (West Samoa Time) UTC +13:00")
    print("San Marino: (Central European Summer Time) UTC +2:00")
    print("Sao Tome and Principe: (Greenwich Mean Time) UTC +0:00")
    print("Saudi Arabia: (Arabia Standard Time) UTC +3:00")
    print("Senegal: (Greenwich Mean Time) UTC +0:00")
    print("Serbia: (Central European Summer Time) UTC +2:00")
    print("Seychelles: (Seychelles Time) UTC +4:00")
    print("Sierra Leone: (Greenwich Mean Time) UTC +0:00")
    print("Singapore: (Singapore Standard Time) UTC +8:00")
    print("Slovakia: (Central European Summer Time) UTC +2:00")
    print("Slovenia: (Central European Summer Time) UTC +2:00")
    print("Solomon Islands: (Solomon Islands Time) UTC +11:00")
    print("Somalia: (East Africa Time) UTC +3:00")
    print("South Africa: (South Africa Standard Time) UTC +2:00")
    print("South Korea: (Korean Standard Time) UTC +9:00")
    print("South Sudan: (East Africa Time) UTC +3:00")
    print("Spain: has two time zones.")
    spanish_timezones()
    print("Sri Lanka: (Indian Standard Time) UTC +5:30")
    print("State of Palestine: (Eastern European Time) UTC +2:00")
    print("Sudan: (Central Africa Time) UTC +2:00")
    print("Suriname: (Suriname Time) UTC -3:00")
    print("Sweden: (Central European Summer Time) UTC +2:00")
    print("Switzerland: (Central European Summer Time) UTC +2:00")
    print("Syria: (Eastern European Summer Time) UTC +3:00")


def t_countries():
    print("Tajikistan: (Tajikistan Time Zone) UTC +5:00")
    print("Tanzania: (East Africa Time) UTC +3:00")
    print("Thailand: (Indochina Time) UTC +7:00")
    print("Timor-Leste: (East Timor Time) UTC +9:00")
    print("Togo: (Greenwich Mean Time) UTC +0:00")
    print("Tonga: (Tonga Time) UTC +13:00")
    print("Trinidad and Tobago: (Atlantic Standard Time) UTC -4:00")
    print("Tunisia: (Central European Time) UTC +1:00")
    print("Turkey: (Turkey Time) UTC +3:00")
    print("Turkmenistan: (Turkmenistan Time) UTC +5:00")
    print("Tuvalu: (Tuvalu Time) UTC +12:00")


def u_countries():
    print("Uganda: (East Africa Time) UTC +3:00")
    print("Ukraine: (Eastern European Summer Time) UTC +3:00")
    print("United Arab Emirates: (Gulf Standard Time) UTC +4:00")
    print("United Kingdom: (British Summer Time) UTC +1:00")
    print("United States of America: has 7 time zones.")
    usa_timezones()
    print("Uruguay: (Uruguay Time) UTC -3:00")
    print("Uzbekistan: (Uzbekistan Time) UTC +5:00")


def v_countries():
    print("Vanuatu: (Vanuatu Time) UTC +11:00")
    print("Venezuela: (Venezuelan Standard Time) UTC -4:00")
    print("Vietnam: (Indochina Time) UTC +7:00")


def y_countries():
    print("Yemen: (Arabia Standard Time) UTC +3:00")


def z_countries():
    print("Zambia: (Central Africa Time) UTC +2:00")
    print("Zimbabwe: (Central Africa Time) UTC +2:00")


def list_0f_timezones():
    a_countries()
    b_countries()
    c_countries()
    d_countries()
    e_countries()
    f_countries()
    g_countries()
    h_countries()
    i_countries()
    j_countries()
    k_countries()
    l_countries()
    m_countries()
    n_countries()
    o_countries()
    p_countries()
    q_countries()
    r_countries()
    s_countries()
    t_countries()
    u_countries()
    v_countries()
    y_countries()
    z_countries()

#this is the main list of countries with info about timezones
#so if u need info on a conutries thing just use one of these


import directory


def time_for_calculate(time_string):
    time_split = time_string.split(':')
    hour = int(time_split[0])
    minute = int(time_split[1])
    return hour, minute


def input_for_convert(from_country, from_time, to_country):
    from_country_timezone = directory.country_and_time[from_country.lower()]
    to_country_timezone = directory.country_and_time[to_country.lower()]
    from_time = from_time.replace(" ", "")

    from_country_tzhour = time_for_calculate(from_country_timezone[0])
    from_country_tzminute = time_for_calculate(from_country_timezone[1])
    to_country_tzhour = time_for_calculate(to_country_timezone[0])
    to_country_tzminute = time_for_calculate(to_country_timezone[1])

    from_time_hour = time_for_calculate(from_time[0])
    from_time_minute = time_for_calculate(from_time[1])

    time_difference_hours = from_country_tzhour - to_country_tzhour
    time_difference_minutes = from_country_tzminute - to_country_tzminute
    to_time_hours = from_time_hour - time_difference_hours
    to_time_minutes = from_time_minute - time_difference_minutes

    if to_time_minutes < 0:
        to_time_hours = to_time_hours - 1
        to_time_minutes = to_time_minutes + 60

    elif to_time_minutes > 60:
        to_time_hours = to_time_hours + 1
        to_time_minutes = to_time_minutes - 60

    if to_time_hours < 0:
        to_time_hours = to_time_hours + 24
        additional_info = " in the previous day."

    elif to_time_hours > 23:
        to_time_hours = to_time_hours - 24
        additional_info = " in the next day."

    else:
        additional_info = ""

    to_time = f"{to_time_hours}:{to_time_minutes}{additional_info}"

    return to_time


#and this is the calculation place


def to_12(time_string):
    time_string_to_use = time_string.replace(" ", "")
    hour = time_string_to_use.split(":")[0]
    minute = time_string_to_use.split(":")[1]
    if 0 < hour < 13:
        addition = " AM"
    elif 13 <= hour < 25:
        hour = str(hour - 12)
        addition = " PM"
    elif hour == 0:
        addition = " AM"
        hour = str(12)

    return hour + minute + addition


def to_24(time_string):
    time_string_to_use = time_string.replace(" ", "")
    hour = int(time_string_to_use.split(":")[0])
    temp = time_string_to_use.split(":")[1]
    minute = temp[:-2]
    addition = temp[2:].lower()
    if addition == "am":
        if hour == 12:
            hour = str(0)
        elif 0 < hour < 12:
            hour = str(hour)
    elif addition == "pm":
        if hour == 12:
            hour = str(hour)
        elif 0 < hour < 12:
            hour = str(hour + 12)

    return hour + minute




def convert(string_input):
    string_to_use = string_input.replace(" ", "")
    if string_to_use.find('d') != -1:
        days = string_to_use.split('d')[0]
        remains1 = string_to_use.split('d')[1]
    else:
        days = 0
        remains1 = string_to_use

    if string_to_use.find('h') != -1:
        hours = remains1.split('h')[0]
        remains2 = remains1.split('h')[1]
    else:
        hours = 0
        remains2 = remains1

    if string_to_use.find('m') != -1:
        minutes = remains2.split('m')[0]
        remains3 = remains2.split('m')[1]
    else:
        minutes = 0
        remains3 = remains2

    days_in_seconds = days * 24 * 60 * 60
    hours_in_second = hours * 60 * 60
    minutes_in_second = minutes * 60
    seconds = remains3

    return_seconds = days_in_seconds + hours_in_second + minutes_in_second + seconds
    return return_seconds

